@@ -3,7 +3,7 @@
 #########################################################
 #########################################################
 ##
-## Tripwire(R) 2.3 Open Source for LINUX install script
+## Tripwire(R) 2.3 Open Source install script
 ##
 #########################################################
 #########################################################
@@ -144,20 +144,23 @@ fi
 ## Miscellaneous configuration parameters.
 ##-------------------------------------------------------
 
+# prefix
+prefix="${prefix:=/usr}"
+
 # License File name
 TWLICENSEFILE="COPYING"
 
 # Default Tripwire configuration file.
 TW_CONFIG_FILE="tw.cfg"
 
-# Name of initial cleartext Tripwire policy file.
+# Name of initial cleartext Tripwire config file.
 CLR_CONFIG_FILE="twcfg.txt"
 
 # Name of initial cleartext Tripwire policy file.
 CLR_POLICY_FILE="twpol.txt"
 
 # Default installation script configuration file.
-INSTALL_CONFIG_FILE="install.cfg"
+INSTALL_CONFIG_FILE="./install/install.cfg"
 
 # Name of the Readme file.
 README="README"
@@ -189,6 +192,16 @@ CLOBBER="false"
 # If prompt==true, ask for confirmation before continuing with install.
 PROMPT="true"
 
+# Guess where the toplevel for the distribution is.
+# A bad guess is the current directory
+TAR_DIR=${TAR_DIR:-${START_DIR}}
+
+OS=`uname -s`
+POLICYSRC="twpol-${OS:=GENERIC}.txt"
+if [ ! -r ${TAR_DIR}/policy/${POLICYSRC} ]
+then POLICYSRC="twpol-GENERIC.txt"
+fi
+
 ##-------------------------------------------------------
 ## Parse the command line.
 ##-------------------------------------------------------
@@ -234,7 +247,7 @@ done
 cat << END_OF_TEXT
 
 Installer program for:
-Tripwire(R) 2.3 Open Source for LINUX
+Tripwire(R) 2.3 Open Source
 
 Copyright (C) 1998-2000 Tripwire (R) Security Systems, Inc.  Tripwire (R)
 is a registered trademark of the Purdue Research Foundation and is
@@ -242,53 +255,6 @@ licensed exclusively to Tripwire (R) Security Systems, Inc.
 
 END_OF_TEXT
 
-##-------------------------------------------------------
-## Are we installing on a supported OS?
-##-------------------------------------------------------
-
-osokay=0
-if [ "$UNAME" != "" ] && [ "$GREP" != "" ]; then
-	unamOS=`uname -s`
-	unamVER=`uname -v -r`
-        if ((echo "$unamOS" | $GREP -i "Linux" > /dev/null) ||
-	    (echo "$unamOS" | $GREP -i "HP-UX" > /dev/null) ||
-	    (echo "$unamOS" | $GREP -i "AIX" > /dev/null)); then
-		unamHW=`uname -m`
-	else
-		unamHW=`uname -p`
-	fi
-	if (echo "$unamOS" | $GREP -i "Linux" > /dev/null); then
-			osokay=1
-	fi
-	if [ "$osokay" -eq 0 ] ; then
-cat << END_OF_TEXT
-
-* * * * Warning * * * *
-The uname command, which tells what operating system is running on this
-machine, returned a result that this installation script did not expect.
-Tripwire 2.3 Open Source for LINUX is supported on Linux Kernels only.
-
-Use of this software with any other operating system is completely unsupported.
-  
-END_OF_TEXT
-
-##-------------------------------------------------------
-## Prompt to continue.
-##-------------------------------------------------------
-
-		if [ "$PROMPT" = "true" ] ; then
-			echo
-			(echo $n "Continue with installation? [y/n] " $c) 1>&2
-			read ans
-			case "$ans" in
-				[yY]*) ;;
-				*) echo "Installation has been halted."
-					exit 1
-					;;
-			esac
-		fi
-	fi
-fi
 
 ##-------------------------------------------------------
 ## Print a message if the user aborts the install.
@@ -312,14 +278,7 @@ path3="TWMAN TWDOCS"
 ##-------------------------------------------------------
 ## Where is the license agreement file?
 ##-------------------------------------------------------
-
-EULA_BASE_DIR=`basename $0`
-EULA_BASE_DIR=`echo $0 | sed s/$EULA_BASE_DIR\$//`
-if [ ! -z "$EULA_BASE_DIR" ] ; then
-	EULA_PATH="${EULA_BASE_DIR}$TWLICENSEFILE"
-else
-	EULA_PATH="$TWLICENSEFILE"
-fi
+EULA_PATH="$TWLICENSEFILE"
 
 ##-------------------------------------------------------
 ## If prompting is turned on, get acceptance from user before moving on.
@@ -327,7 +286,7 @@ fi
 
 if [ "$PROMPT" = "true" ] ; then
   echo
-  echo "LICENSE AGREEMENT for Tripwire(R) 2.3 Open Source for LINUX"
+  echo "LICENSE AGREEMENT for Tripwire(R) 2.3 Open Source"
   echo
   echo "Please read the following license agreement.  You must accept the"
   echo "agreement to continue installing Tripwire."
@@ -484,13 +443,9 @@ echo "----------------------------------------------"
 echo "Verifying existence of binaries..."
 echo
 
-BASE_DIR=`basename $0`
-BASE_DIR=`echo $0 | sed s/$BASE_DIR\$//`
+BASE_DIR="./"
 if [ ! -z "$BASE_DIR" ] ; then
-	TAR_DIR="${BASE_DIR}"
-	BIN_DIR="${BASE_DIR}bin/i686-pc-linux_r"
-else
-	TAR_DIR="${BASE_DIR}"
+	BIN_DIR="${BASE_DIR}bin"
 fi
 
 CWD=`pwd`
@@ -621,23 +576,24 @@ README_LOC=${TWDOCS}/$REL_NOTES
 f1=' ff=$README ; d="" ; dd=$TWDOCS ; rr=0444 '
 f2=' ff=$REL_NOTES ; d="" ; dd=$TWDOCS ; rr=0444 '
 f3=' ff=$TWLICENSEFILE ; d="" ; dd=$TWDOCS ; rr=0444 '
-f4=' ff=tripwire ; d="/bin/i686-pc-linux_r" ; dd=$TWBIN ; rr=0550 '
-f5=' ff=twadmin ; d="/bin/i686-pc-linux_r" ; dd=$TWBIN ; rr=0550 '
-f6=' ff=twprint ; d="/bin/i686-pc-linux_r" ; dd=$TWBIN ; rr=0550 '
-f7=' ff=siggen ; d="/bin/i686-pc-linux_r" ; dd=$TWBIN ; rr=0550 '
+#f4=' ff=tripwire ; d="/bin" ; dd=$TWBIN ; rr=0550 '
+#f5=' ff=twadmin ; d="/bin" ; dd=$TWBIN ; rr=0550 '
+#f6=' ff=twprint ; d="/bin" ; dd=$TWBIN ; rr=0550 '
+#f7=' ff=siggen ; d="/bin" ; dd=$TWBIN ; rr=0550 '
 f8=' ff=TRADEMARK ; d="" ; dd=$TWDOCS ; rr=0444 '
-f9=' ff=policyguide.txt ; d="" ; dd=$TWDOCS ; rr=0444 '
-f10=' ff=twpol.txt ; d="/policy/" ; dd=$TWPOLICY ; rr=0640 '
-f11=' ff=twpolicy.4 ; d="/man/man4" ; dd=$TWMAN/man4 ; rr=0444 '
-f12=' ff=twconfig.4 ; d="/man/man4" ; dd=$TWMAN/man4 ; rr=0444 '
-f13=' ff=twfiles.5 ; d="/man/man5" ; dd=$TWMAN/man5 ; rr=0444 '
-f14=' ff=siggen.8 ; d="/man/man8" ; dd=$TWMAN/man8 ; rr=0444 '
-f15=' ff=tripwire.8 ; d="/man/man8" ; dd=$TWMAN/man8 ; rr=0444 '
-f16=' ff=twadmin.8 ; d="/man/man8" ; dd=$TWMAN/man8 ; rr=0444 '
-f17=' ff=twintro.8 ; d="/man/man8" ; dd=$TWMAN/man8 ; rr=0444 '
-f18=' ff=twprint.8 ; d="/man/man8" ; dd=$TWMAN/man8 ; rr=0444 '
+f9=' ff=policyguide.txt ; d="/policy" ; dd=$TWDOCS ; rr=0444 '
+f10=' ff=${POLICYSRC} ; d="/policy" ; dd=$TWPOLICY ; rr=0640 '
+#f11=' ff=twpolicy.4 ; d="/man/man4" ; dd=$TWMAN/man4 ; rr=0444 '
+#f12=' ff=twconfig.4 ; d="/man/man4" ; dd=$TWMAN/man4 ; rr=0444 '
+#f13=' ff=twfiles.5 ; d="/man/man5" ; dd=$TWMAN/man5 ; rr=0444 '
+#f14=' ff=siggen.8 ; d="/man/man8" ; dd=$TWMAN/man8 ; rr=0444 '
+#f15=' ff=tripwire.8 ; d="/man/man8" ; dd=$TWMAN/man8 ; rr=0444 '
+#f16=' ff=twadmin.8 ; d="/man/man8" ; dd=$TWMAN/man8 ; rr=0444 '
+#f17=' ff=twintro.8 ; d="/man/man8" ; dd=$TWMAN/man8 ; rr=0444 '
+#f18=' ff=twprint.8 ; d="/man/man8" ; dd=$TWMAN/man8 ; rr=0444 '
 
-loosefiles="f1 f2 f3 f4 f5 f6 f7 f8 f9 f10 f11 f12 f13 f14 f15 f16 f17 f18"
+# Binaries and manpages are already installed by the install target
+loosefiles="f1 f2 f3 f8 f9 f10"
 
 for i in $loosefiles; do
 	eval "eval \"\$$i\""
@@ -665,13 +621,9 @@ done
 ## Set default values for Tripwire file names.
 ##-------------------------------------------------------
 
-HOST_NAME='localhost'
-(uname -n) 2> /dev/null 1>&2
-if [ $? -eq 0 ]; then
-    HOST_NAME=`uname -n`
-fi
+HOST_NAME=`uname -n 2>/dev/null`
 
-LOCAL_KEY="${TWLOCALKEYDIR}/${HOST_NAME}-local.key"
+LOCAL_KEY="${TWLOCALKEYDIR}/${HOST_NAME:=localhost}-local.key"
 SITE_KEY="${TWSITEKEYDIR}/site.key"
 CONFIG_FILE="${TWPOLICY}/$TW_CONFIG_FILE"  # Signed config file
 POLICY_FILE="${TWPOLICY}/tw.pol"        # Signed policy file
@@ -883,15 +835,16 @@ sed '/@@section GLOBAL/,/@@section FS/  {
   s?^\(TWLKEY=\).*$?\1'\""$TWLOCALKEYDIR"\"';?
   s?^\(TWREPORT=\).*$?\1'\""$TWREPORT"\"';?
   s?^\(HOSTNAME=\).*$?\1'"$HOST_NAME"';?
-}' "${TXT_POL}" > "${TXT_POL}.tmp"
+}' "${TWPOLICY}/${POLICYSRC}" > "${TXT_POL}.tmp"
 
 # copy the tmp file back over the default policy
-cp "${TXT_POL}" "${TXT_POL}.bak"
+[ -f "${TXT_POL}" ] && cp "${TXT_POL}" "${TXT_POL}.bak"
 mv "${TXT_POL}.tmp" "${TXT_POL}"
+rm -f "${TWPOLICY}/${POLICYSRC}"
 
 # reset rights on the policy files to 640
-chmod 640 "$TXT_POL"
-chmod 640 "${TXT_POL}.bak"
+[ -f "${TXT_POL}" ] && chmod 640 "$TXT_POL"
+[ -f "${TXT_POL}.bak" ] && chmod 640 "${TXT_POL}.bak"
 
 
 ##=======================================================
@@ -968,7 +921,7 @@ The installation succeeded.
 
 Please refer to $README_LOC
 for release information and to the printed user documentation
-for further instructions on using Tripwire 2.3 Open Source for LINUX.
+for further instructions on using Tripwire 2.3 Open Source.
 
 END_OF_TEXT
 
