@@ -45,7 +45,7 @@
 #include <fcntl.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <iostream.h>
+#include <iostream>
 #include "file.h"
 #include "stringutil.h"
 
@@ -896,7 +896,7 @@ void cLockedTemporaryFileArchive::OpenReadWrite( const TCHAR* filename, uint32 o
     // create file
 
     // set up flags
-    uint32 flags = cFile::OPEN_WRITE | cFile::OPEN_LOCKED_TEMP | cFile::OPEN_CREATE;
+    uint32 flags = cFile::OPEN_WRITE | cFile::OPEN_LOCKED_TEMP | cFile::OPEN_CREATE | cFile::OPEN_EXCLUSIVE;
     if ( openFlags & FA_OPEN_TRUNCATE ) 
       flags |= cFile::OPEN_TRUNCATE;
     if ( openFlags & FA_OPEN_TEXT ) 
