@@ -79,12 +79,12 @@
 #define major(x) ((int)((x) >> 8) & 0xff)
 #define minor(x) ((int)((x) & 0xff))
 #else
-#if IS_LITTLE_ENDIAN
-#define major(x) (int)(((char*)&(x))[1])
-#define minor(x) (int)(((char*)&(x))[0])
-#else
+#ifdef WORDS_BIGENDIAN
 #define major(x) (int)(((char*)&(x))[2])
 #define minor(x) (int)(((char*)&(x))[3])
+#else
+#define major(x) (int)(((char*)&(x))[1])
+#define minor(x) (int)(((char*)&(x))[0])
 #endif
 #endif
 #endif /* !major */
