@@ -255,8 +255,10 @@ cHierDatabaseIter& cHierDatabaseIter::operator=( const cHierDatabaseIter& rhs )
 	}
 	else
 	{
-		int offset	= rhs.mIter - rhs.mEntries.begin();
-		mIter		= mEntries.begin() + offset;
+		EntryArray::const_iterator p1, p2;
+		p1 = rhs.mIter;
+		p2 = rhs.mEntries.begin();
+		mIter		= mEntries.begin() + (p1 - p2);
 	}
 
 	return (*this);
