@@ -36,15 +36,16 @@
 #include "stdfco.h"
 #include "signature.h"
 #include "core/errorgeneral.h"
-#include "core/md5.h"
-#include "core/crc32.h"
 #include "core/serializer.h"
-#include "core/sha.h"
-#include "core/haval.h"
 #include <fstream>
 #include <iomanip>
 #include "fcoundefprop.h"
 #include "core/archive.h"
+#ifndef HAVE_OPENSSL_MD5_H
+# ifdef HAVE_STRINGS_H
+# include <strings.h>		/* for bcopy(), this is only needed for Solaris */
+# endif
+#endif
 
 using namespace std;
 
@@ -464,6 +465,7 @@ IMPLEMENT_TYPEDSERIALIZABLE(cMD5Signature,  _T("cMD5Signature"), 0, 1)
 cMD5Signature::cMD5Signature()
 {
 	memset( mMD5Info.digest, 0, sizeof( mMD5Info.digest ) );
+	memset( md5_digest, 0, MD5_DIGEST_LENGTH );
 }
 
 cMD5Signature::~cMD5Signature()
@@ -472,17 +474,30 @@ cMD5Signature::~cMD5Signature()
 
 void cMD5Signature::Init()
 {
+#ifdef HAVE_OPENSSL_MD5_H
+    MD5_Init( &mMD5Info );
+#else
     MD5Init( &mMD5Info );
+#endif
 }
 
 void cMD5Signature::Update( const byte* pbData, int cbDataLen )
 {
+#ifdef HAVE_OPENSSL_MD5_H
+    MD5_Update( &mMD5Info, (uint8*)pbData, cbDataLen );
+#else
     MD5Update( &mMD5Info, (uint8*)pbData, cbDataLen );
+#endif
 }
 
 void cMD5Signature::Finit()
 {
+#ifdef HAVE_OPENSSL_MD5_H
+    MD5_Final( md5_digest, &mMD5Info );
+#else
     MD5Final( &mMD5Info );
+    bcopy(mMD5Info.digest, md5_digest, MD5_DIGEST_LENGTH);
+#endif
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -491,11 +506,12 @@ TSTRING cMD5Signature::AsString() const
 {
     TSTRING ret;
 	char buf[24];
+	int length;
 
     ASSERT( sizeof( uint8 ) == sizeof( byte ) ); /* everything breaks otherwise */
-	btob64((byte*)mMD5Info.digest, buf, 128);
+	btob64((byte*)md5_digest, buf, SIG_BYTE_SIZE*8);
 		//converting to base64 representation.
-	int length = strlen(buf);
+	length = strlen(buf);
 
 #ifdef _UNICODE		//making it TSTRING sensitive
 	ret.resize(length);
@@ -515,10 +531,11 @@ TSTRING cMD5Signature::AsStringHex() const
 	TCHAR stringBuffer[128];
 	TCHAR sigStringOut[128];
 	sigStringOut[0] = '\0';
+	uint8		*dbuf = (uint8 *)md5_digest;
 
 	for(int i = 0; i < SIG_BYTE_SIZE; ++i)
 	{
-		_stprintf(stringBuffer, _T("%02lx"), mMD5Info.digest[i]);
+		_stprintf(stringBuffer, _T("%02lx"), dbuf[i]);
 		_tcscat(sigStringOut, stringBuffer);
 	}
 	ret.append(sigStringOut);
@@ -531,7 +548,7 @@ bool cMD5Signature::IsEqual(const iSignature& rhs) const
 	if (this == &rhs)
 		return true;
 	else {
-		return (memcmp(mMD5Info.digest, ((cMD5Signature&)rhs).mMD5Info.digest, SIG_BYTE_SIZE) == 0);
+		return (memcmp(md5_digest, ((cMD5Signature&)rhs).md5_digest, SIG_BYTE_SIZE) == 0);
 	}
 }
 
@@ -540,12 +557,12 @@ void cMD5Signature::Read(iSerializer* pSerializer, int32 version)
 	if (version > Version())
 		ThrowAndAssert(eSerializerVersionMismatch(_T("MD5 Read")));
 
-	pSerializer->ReadBlob(mMD5Info.digest, SIG_BYTE_SIZE);
+	pSerializer->ReadBlob(md5_digest, SIG_BYTE_SIZE);
 }
 
 void cMD5Signature::Write(iSerializer* pSerializer) const
 {
-	pSerializer->WriteBlob(mMD5Info.digest, SIG_BYTE_SIZE);
+	pSerializer->WriteBlob(md5_digest, SIG_BYTE_SIZE);
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -554,7 +571,7 @@ void cMD5Signature::Write(iSerializer* pSerializer) const
 void cMD5Signature::Copy(const iFCOProp* rhs)
 {
 	ASSERT(GetType() == rhs->GetType());
-	memcpy(&mMD5Info.digest, &(static_cast<const cMD5Signature*>(rhs)->mMD5Info.digest), SIG_BYTE_SIZE);
+	memcpy(md5_digest, &(static_cast<const cMD5Signature*>(rhs)->md5_digest), SIG_BYTE_SIZE);
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -565,7 +582,8 @@ IMPLEMENT_TYPEDSERIALIZABLE(cSHASignature,  _T("cSHASignature"), 0, 1)
 
 cSHASignature::cSHASignature()
 {
-    memset( mSHAInfo.digest, 0, sizeof( mSHAInfo.digest ) );
+    memset( &mSHAInfo, 0, sizeof( mSHAInfo ) );
+    memset( sha_digest, 0, SHA_DIGEST_LENGTH );
 }
 
 cSHASignature::~cSHASignature()
@@ -573,18 +591,47 @@ cSHASignature::~cSHASignature()
 
 void cSHASignature::Init()
 {
+#ifdef HAVE_OPENSSL_SHA_H
+    SHA1_Init( &mSHAInfo );
+#else
     shsInit( &mSHAInfo );
+#endif
 }
 
 void cSHASignature::Update( const byte* pbData, int cbDataLen )
 {    
     ASSERT( sizeof( byte ) == sizeof( uint8 ) );
+#ifdef HAVE_OPENSSL_SHA_H
+    SHA1_Update( &mSHAInfo, (uint8*)pbData, cbDataLen );
+#else
     shsUpdate( &mSHAInfo, (uint8*)pbData, cbDataLen );
+#endif
 }
 
 void cSHASignature::Finit()
 {
+#ifdef HAVE_OPENSSL_SHA_H
+    SHA1_Final( (unsigned char *)sha_digest, &mSHAInfo );
+    memset( &mSHAInfo, 0, sizeof( mSHAInfo ) );
+#else
     shsFinal( &mSHAInfo );
+    bcopy(&mSHAInfo.digest, sha_digest, SHA_DIGEST_LENGTH);
+    {
+	/* sha_digest is a byte array, so can't be in
+	 * host order.
+	 */
+    int i;
+    uint32 *j = (uint32 *)sha_digest;
+    uint32 *k = (uint32 *)&mSHAInfo.digest;
+    for(int i=0; i<SIG_UINT32_SIZE; i++)
+# ifdef WORDS_BIGENDIAN
+	j[i] = k[i];
+# else
+	j[i] = (  (k[i] & 0x00ff) << 24 ) | ( (k[i] & 0xff00) << 8)| 
+		( (k[i] >> 8) & 0xff00  ) | ( (k[i] >> 24) & 0x00ff );
+# endif //WORDS_BIGENDIAN
+    }
+#endif
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -594,10 +641,11 @@ TSTRING cSHASignature::AsString(void) const
 	TSTRING ret;
 	char* ps_signature;
 	char buf[100];
+	int length;
 
-	ps_signature = pltob64((uint32*)mSHAInfo.digest, buf, SIG_UINT32_SIZE);
+	ps_signature = btob64((uint8*)sha_digest, buf, SIG_UINT32_SIZE*sizeof(uint32)*8);
 		//converting to base64 representation.
-	int length = strlen(ps_signature);
+	length = strlen(ps_signature);
 
 #ifdef _UNICODE		//making it TSTRING sensitive
 	ret.resize(length);
@@ -616,10 +664,11 @@ TSTRING cSHASignature::AsStringHex() const
 	TCHAR stringBuffer[128];
 	TCHAR sigStringOut[128];
 	sigStringOut[0] = '\0';
+	uint8		*dbuf = (uint8 *)sha_digest;
     
-	for (int i=0; i < SIG_UINT32_SIZE; ++i)
+	for (int i=0; i < SIG_UINT32_SIZE*(int)sizeof(uint32); ++i)
 	{
-		_stprintf(stringBuffer, _T("%08x"), mSHAInfo.digest[i]);
+		_stprintf(stringBuffer, _T("%02x"), dbuf[i]);
 		_tcscat(sigStringOut, stringBuffer);
 	}
 	ret.append(sigStringOut);
@@ -700,10 +749,11 @@ TSTRING cHAVALSignature::AsString() const
 {
     TSTRING ret;
 	char buf[24];
+	int length;
 
 	btob64((byte*)mSignature, buf, 128);
 		//converting to base64 representation.
-	int length = strlen(buf);
+	length = strlen(buf);
 
 #ifdef _UNICODE		//making it TSTRING sensitive
 	ret.resize(length);
