@@ -228,13 +228,8 @@ bool cMailMessageUtil::ReadDate( TSTRING& strDateBuf )
 {
     bool fGotDate = false;
 
-#if !USES_BIN_DATE
+#if HAVE_STRFTIME
 
-	int64 now = cSystemInfo::GetExeStartTime();
-	strDateBuf = cTimeUtil::GetRFC822Date(cTimeUtil::TimeToDateGMT(now));
-	fGotDate = true;
-
-#else
 	TCHAR szDate[1024];
 	struct tm *tm = NULL;
 	
@@ -250,9 +245,14 @@ bool cMailMessageUtil::ReadDate( TSTRING& strDateBuf )
 		strDateBuf = szDate;
 		fGotDate = true;
 	}
-	
-	
-#endif // !USES_BIN_DATE
+
+#else
+
+	int64 now = cSystemInfo::GetExeStartTime();
+	strDateBuf = cTimeUtil::GetRFC822Date(cTimeUtil::TimeToDateGMT(now));
+	fGotDate = true;
+
+#endif // HAVE_STRFTIME
 
     return fGotDate;
 }
@@ -509,9 +509,9 @@ std::string& cMailMessageUtil::LFToCRLF( std::string& sIn )
     std::string::size_type stringSize = 0;
     std::string::const_iterator at;
     std::string::difference_type charSize;
-    for( at = sIn.begin(), charSize = ( tss::strinc( at ) - at );
+    for( at = sIn.begin(), charSize = ( (*at ? at+1 : at) - at );
          at != sIn.end();
-         at += charSize, charSize = ( tss::strinc( at ) - at ) )
+         at += charSize, charSize = ( (*at ? at+1 : at) - at ) )
     {
         ASSERT( charSize > 0 );
 
