@@ -54,7 +54,11 @@
 #include <arpa/inet.h>
 #include <sys/utsname.h>
 
-#if IS_SOLARIS || IS_AIX
+/* Some systems like Solaris and AIX don't define
+ * INADDR_NONE, but it's pretty standard.  If not,
+ * then the OS _should_ define it for us.
+ */
+#ifndef INADDR_NONE
 #define INADDR_NONE 0xffffffff
 #endif
 
@@ -62,7 +66,7 @@
 
 #define INVALID_SOCKET -1
 
-#if !(IS_SOLARIS && IS_IX86)	/* solaris/x86 has gethostname */
+#ifndef HAVE_GETHOSTNAME
 static int gethostname( char* name, int namelen )
 {
 	name[0] = '\0';
