@@ -672,7 +672,9 @@ void cTWUtil::ReadConfigText(const TCHAR* filename, TSTRING& configText, cArchiv
         throw eSerializerInputStreamFmt(_T(""), filename, eSerializer::TY_FILE);
     }
 
+#if 0	// XXX: This is broken, what the h*ll are they trying to write here? -PH
     d.TraceDebug("Found a file header of type %d.\n", fileHeader.GetID());
+#endif
 
     // check for a mismatched header
     if (fileHeader.GetID() != cConfigFile::GetFileHeaderID())
@@ -775,7 +777,9 @@ void cTWUtil::ReadConfigText(cArchive &arch, TSTRING& configText, cArchive* pBag
         throw eSerializerInputStreamFmt(_T(""), filename.c_str(), eSerializer::TY_FILE);
     }
 
+#if 0	// XXX: This is broken, how can you convert a class to an int??? -PH
     d.TraceDebug("Found a file header of type %d.\n", fileHeader.GetID());
+#endif
 
     // check for a mismatched header
     if (fileHeader.GetID() != cConfigFile::GetFileHeaderID())
@@ -971,7 +975,7 @@ const cElGamalSigPrivateKey* cTWUtil::CreatePrivateKey(cKeyFile& keyFile, const
 
 		passphrase = usePassphrase;
 
-        #if IS_LITTLE_ENDIAN
+        #ifndef WORDS_BIGENDIAN
         passphrase.swapbytes();
         #endif
 
@@ -1012,7 +1016,7 @@ const cElGamalSigPrivateKey* cTWUtil::CreatePrivateKey(cKeyFile& keyFile, const
         // sleep to hinder brute force (dictionary, etc.) attacks
         iFSServices::GetInstance()->Sleep( nSecs );
 
-        #if IS_LITTLE_ENDIAN
+        #ifndef WORDS_BIGENDIAN
         passphrase.swapbytes();
         #endif
 
@@ -1048,7 +1052,7 @@ void cTWUtil::CreatePrivateKey(cPrivateKeyProxy& proxy, cKeyFile& keyFile, const
 
 		passphrase = usePassphrase;
 
-        #if IS_LITTLE_ENDIAN
+        #ifndef WORDS_BIGENDIAN
         passphrase.swapbytes();
         #endif
 
@@ -1087,7 +1091,7 @@ void cTWUtil::CreatePrivateKey(cPrivateKeyProxy& proxy, cKeyFile& keyFile, const
         // sleep to hinder brute force (dictionary, etc.) attacks
         iFSServices::GetInstance()->Sleep( nSecs );
 
-        #if IS_LITTLE_ENDIAN
+        #ifndef WORDS_BIGENDIAN
         passphrase.swapbytes();
         #endif
 
@@ -1406,7 +1410,7 @@ bool cTWUtil::ConfirmYN(const TCHAR* prompt)
 		for (x = 0; s[x] && iswctype(s[x], wctype("space") ); x++)
 			;
 #else
-		for (x = 0; s[x] && isspace(s[x]); x++)
+		for (x = 0; s[x] && std::isspace<TCHAR>( s[x], std::locale() ); x++)
 			;
 #endif
 			
